@@ -1,6 +1,7 @@
 package main
 
 import (
+	"context"
 	goflag "flag"
 	"fmt"
 	"math/rand"
@@ -13,13 +14,15 @@ import (
 	utilflag "k8s.io/component-base/cli/flag"
 	"k8s.io/component-base/logs"
 
-	operatorcmd "github.com/openshift/cluster-kube-controller-manager-operator/pkg/cmd/operator"
-	"github.com/openshift/cluster-kube-controller-manager-operator/pkg/cmd/render"
-	"github.com/openshift/cluster-kube-controller-manager-operator/pkg/cmd/resourcegraph"
-	"github.com/openshift/cluster-kube-controller-manager-operator/pkg/operator"
 	"github.com/openshift/library-go/pkg/operator/staticpod/certsyncpod"
 	"github.com/openshift/library-go/pkg/operator/staticpod/installerpod"
 	"github.com/openshift/library-go/pkg/operator/staticpod/prune"
+
+	operatorcmd "github.com/openshift/cluster-kube-controller-manager-operator/pkg/cmd/operator"
+	"github.com/openshift/cluster-kube-controller-manager-operator/pkg/cmd/recoverycontroller"
+	"github.com/openshift/cluster-kube-controller-manager-operator/pkg/cmd/render"
+	"github.com/openshift/cluster-kube-controller-manager-operator/pkg/cmd/resourcegraph"
+	"github.com/openshift/cluster-kube-controller-manager-operator/pkg/operator"
 )
 
 func main() {
@@ -31,19 +34,19 @@ func main() {
 	logs.InitLogs()
 	defer logs.FlushLogs()
 
-	command := NewSSCSCommand()
+	command := NewSSCSCommand(context.Background())
 	if err := command.Execute(); err != nil {
-		fmt.Fprintf(os.Stderr, "%v\n", err)
+		_, _ = fmt.Fprintf(os.Stderr, "%v\n", err)
 		os.Exit(1)
 	}
 }
 
-func NewSSCSCommand() *cobra.Command {
+func NewSSCSCommand(ctx context.Context) *cobra.Command {
 	cmd := &cobra.Command{
 		Use:   "cluster-kube-controller-manager-operator",
 		Short: "OpenShift cluster kube-controller-manager operator",
 		Run: func(cmd *cobra.Command, args []string) {
-			cmd.Help()
+			_ = cmd.Help()
 			os.Exit(1)
 		},
 	}
@@ -54,6 +57,7 @@ func NewSSCSCommand() *cobra.Command {
 	cmd.AddCommand(prune.NewPrune())
 	cmd.AddCommand(resourcegraph.NewResourceChainCommand())
 	cmd.AddCommand(certsyncpod.NewCertSyncControllerCommand(operator.CertConfigMaps, operator.CertSecrets))
+	cmd.AddCommand(recoverycontroller.NewCertRecoveryControllerCommand(ctx))
 
 	return cmd
 }
